@@ -60,8 +60,8 @@ void qdsrc( int is, complex double v, complex double *e )
   data.icon1[is]= i;
   dataj.s= data.si[is]*.5;
   curd= CCJ* v/(( log(2.0 * dataj.s/ data.bi[is])-1.0) *
-	  ( segj.bx[segj.jsno-1] * cos( TP* dataj.s) +
-		segj.cx[segj.jsno-1] * sin( TP* dataj.s))* data.wlam);
+	  ( segj.bx[segj.jsno-1] * cos( TWOPI* dataj.s) +
+		segj.cx[segj.jsno-1] * sin( TWOPI* dataj.s))* data.wlam);
   vsorc.vqds[vsorc.nqds]= v;
   vsorc.iqds[vsorc.nqds]= is+1;
   vsorc.nqds++;
@@ -290,8 +290,8 @@ void cabc( complex double *curx)
 		data.icon1[i]= jx;
 		sh= data.si[i]*.5;
 		curd= CCJ* vsorc.vqds[is]/( (log(2.0* sh/ data.bi[i])-1.0) *
-			(segj.bx[segj.jsno-1]* cos(TP* sh)+ segj.cx[segj.jsno-1] *
-			 sin(TP* sh))* data.wlam );
+			(segj.bx[segj.jsno-1]* cos(TWOPI* sh)+ segj.cx[segj.jsno-1] *
+			 sin(TWOPI* sh))* data.wlam );
 		ar= creal( curd);
 		ai= cimag( curd);
 
@@ -380,8 +380,8 @@ void intrp( double x, double y, complex double *f1,
   {
 	first_call = FALSE;
 	size_t mreq = 3*sizeof(int);
-	mem_alloc( (void *)&nda,  mreq, "in calculations.c");
-	mem_alloc( (void *)&ndpa, mreq, "in calculations.c");
+	mem_alloc( (void **)&nda,  mreq, "in calculations.c");
+	mem_alloc( (void **)&ndpa, mreq, "in calculations.c");
 	nda[0] = 11; nda[1] = 17; nda[2] = 9;
 	ndpa[0] = 110; ndpa[1] = 85; ndpa[2] = 72;
   }
@@ -1226,11 +1226,11 @@ trio( int j )
 	  {
 		segj.maxcon = segj.jsno +1;
 		size_t mreq = (size_t)segj.maxcon * sizeof(int);
-		mem_realloc( (void *)&segj.jco, mreq, "in calculations.c" );
+		mem_realloc( (void **)&segj.jco, mreq, "in calculations.c" );
 		mreq = (size_t)segj.maxcon * sizeof(double);
-		mem_realloc( (void *) &segj.ax, mreq, "in calculations.c" );
-		mem_realloc( (void *) &segj.bx, mreq, "in calculations.c" );
-		mem_realloc( (void *) &segj.cx, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.ax, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.bx, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.cx, mreq, "in calculations.c" );
 	  }
 
 	  sbf( j, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
@@ -1258,11 +1258,11 @@ trio( int j )
 	  {
 		segj.maxcon = segj.jsno +1;
 		size_t mreq = (size_t)segj.maxcon * sizeof(int);
-		mem_realloc( (void *)&segj.jco, mreq, "in calculations.c" );
+		mem_realloc( (void **)&segj.jco, mreq, "in calculations.c" );
 		mreq = (size_t)segj.maxcon * sizeof(double);
-		mem_realloc( (void *) &segj.ax, mreq, "in calculations.c" );
-		mem_realloc( (void *) &segj.bx, mreq, "in calculations.c" );
-		mem_realloc( (void *) &segj.cx, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.ax, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.bx, mreq, "in calculations.c" );
+		mem_realloc( (void **) &segj.cx, mreq, "in calculations.c" );
 	  }
 
 	  sbf( jcox, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
@@ -1305,11 +1305,11 @@ trio( int j )
   {
 	segj.maxcon = segj.jsno +1;
 	size_t mreq = (size_t)segj.maxcon * sizeof(int);
-	mem_realloc( (void *)&segj.jco, mreq, "in calculations.c" );
+	mem_realloc( (void **)&segj.jco, mreq, "in calculations.c" );
 	mreq = (size_t)segj.maxcon * sizeof(double);
-	mem_realloc( (void *) &segj.ax, mreq, "in calculations.c" );
-	mem_realloc( (void *) &segj.bx, mreq, "in calculations.c" );
-	mem_realloc( (void *) &segj.cx, mreq, "in calculations.c" );
+	mem_realloc( (void **) &segj.ax, mreq, "in calculations.c" );
+	mem_realloc( (void **) &segj.bx, mreq, "in calculations.c" );
+	mem_realloc( (void **) &segj.cx, mreq, "in calculations.c" );
   }
 
   sbf( j, j, &segj.ax[jsnox], &segj.bx[jsnox], &segj.cx[jsnox]);
@@ -1323,7 +1323,7 @@ trio( int j )
 /* cang returns the phase angle of a complex number in degrees. */
 double cang( complex double z )
 {
-  return( carg(z)*TD );
+  return( carg(z)*TODEG );
 }
 
 /*-----------------------------------------------------------------------*/
@@ -1350,8 +1350,8 @@ zint( double sigl, double rolam, complex double *zint )
 
 #define th(d) ( (((((cc1*(d)+cc2)*(d)+cc3)*(d)+cc4)*(d)+cc5)*(d)+cc6)*(d) + cc7 )
 #define ph(d) ( (((((cc8*(d)+cc9)*(d)+cc10)*(d)+cc11)*(d)+cc12)*(d)+cc13)*(d)+cc14 )
-#define f(d)  ( csqrt(POT/(d))*cexp(-cn*(d)+th(-8.0/x)) )
-#define g(d)  ( cexp(cn*(d)+th(8.0/x))/csqrt(TP*(d)) )
+#define f(d)  ( csqrt(PITWO/(d))*cexp(-cn*(d)+th(-8.0/x)) )
+#define g(d)  ( cexp(cn*(d)+th(8.0/x))/csqrt(TWOPI*(d)) )
 
   double x;
   double tpcmu = 2.368705e+3;
