@@ -124,6 +124,7 @@ on_main_save_activate        (GtkMenuItem     *menuitem,
 							  gpointer         user_data)
 {
   char saveas[96];
+  size_t s = sizeof( saveas );
 
   /* Count number of structure image files saved of geometry,
    * currents or charges, to avoid over-writing saved files */
@@ -135,12 +136,11 @@ on_main_save_activate        (GtkMenuItem     *menuitem,
   /* Make the structure image save file name from input file
    * name. The count of each image type saved is incremented */
   if( isFlagSet(DRAW_CURRENTS) )
-	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "current", ++ccr, "png" );
+	snprintf( saveas, s, "%s-%s_%03d.%s", infile, "current", ++ccr, "png" );
   else if( isFlagSet(DRAW_CHARGES) )
-	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
+	snprintf( saveas, s, "%s-%s_%03d.%s", infile, "charge", ++cch, "png" );
   else
-	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
-  saveas[95] = '\0';
+	snprintf( saveas, s, "%s-%s_%03d.%s", infile, "geometry", ++cgm, "png" );
 
   saveas_pixmap = structure_pixmap;
   saveas_pixmap_width  = structure_pixmap_width;
@@ -221,7 +221,7 @@ on_main_rdpattern_activate             (GtkMenuItem     *menuitem,
 		  rdpattern_window, "rdpattern_incline_spinbutton"));
 	rdpattern_frequency = GTK_SPIN_BUTTON(lookup_widget(
 		  rdpattern_window, "rdpattern_freq_spinbutton"));
-	rdpattern_zoom_spinbutton = GTK_SPIN_BUTTON(lookup_widget(
+	rdpattern_zoom = GTK_SPIN_BUTTON(lookup_widget(
 		  rdpattern_window, "rdpattern_zoom_spinbutton"));
 	rdpattern_fstep_entry = GTK_ENTRY(lookup_widget(
 		  rdpattern_window, "rdpattern_fstep_entry")) ;
@@ -305,7 +305,20 @@ on_common_projection_activate          (GtkMenuItem     *menuitem,
   /* Enable syncing of projection params
    * for structure and rad pattern drawing */
   if( gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem)) )
+  {
+	if( isFlagSet(DRAW_ENABLED) )
+	{
+	  rdpattern_proj_params.Wr = structure_proj_params.Wr;
+	  rdpattern_proj_params.Wi = structure_proj_params.Wi;
+	  New_Viewer_Angle(
+		  rdpattern_proj_params.Wr,
+		  rdpattern_proj_params.Wi,
+		  rotate_rdpattern,
+		  incline_rdpattern,
+		  &rdpattern_proj_params );
+	}
 	SetFlag( COMMON_PROJECTION );
+  }
   else
 	ClearFlag( COMMON_PROJECTION );
 }
@@ -332,6 +345,9 @@ on_main_x_axis_clicked                 (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 0.0, 0.0, rotate_structure,
 	  incline_structure, &structure_proj_params );
+  if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 0.0, 0.0, rotate_rdpattern,
+		incline_rdpattern, &rdpattern_proj_params );
 }
 
 
@@ -342,6 +358,9 @@ on_main_y_axis_clicked                 (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 90.0, 0.0, rotate_structure,
 	  incline_structure, &structure_proj_params );
+  if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 90.0, 0.0, rotate_rdpattern,
+		incline_rdpattern, &rdpattern_proj_params );
 }
 
 
@@ -352,6 +371,9 @@ on_main_z_axis_clicked                 (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 0.0, 90.0, rotate_structure,
 	  incline_structure, &structure_proj_params );
+  if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 0.0, 90.0, rotate_rdpattern,
+		incline_rdpattern, &rdpattern_proj_params );
 }
 
 
@@ -362,38 +384,53 @@ on_main_default_view_clicked           (GtkButton       *button,
   /* Projection at 45 deg rotation and inclination */
   New_Viewer_Angle( 45.0, 45.0, rotate_structure,
 	  incline_structure, &structure_proj_params );
+  if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 45.0, 45.0, rotate_rdpattern,
+		incline_rdpattern, &rdpattern_proj_params );
 }
 
 
 void
-on_main_rotate_spinbutton_value_changed(GtkSpinButton   *spinbutton,
-										gpointer         user_data)
+on_main_rotate_spinbutton_value_changed(
+	GtkSpinButton   *spinbutton,
+	gpointer         user_data)
 {
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
+
   /* Get new "rotate" structure angle from spinbutton */
   structure_proj_params.Wr = gtk_spin_button_get_value(spinbutton);
-  New_Structure_Projection_Angle();
 
   /* Sync rad pattrern window spinbutton if enabled */
   if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
 	gtk_spin_button_set_value(
 		rotate_rdpattern, (gdouble)structure_proj_params.Wr );
+
+  New_Structure_Projection_Angle();
+  gtk_spin_button_update( spinbutton );
 }
 
 
-void
-on_main_incline_spinbutton_value_changed( GtkSpinButton   *spinbutton,
-										  gpointer         user_data)
+  void
+on_main_incline_spinbutton_value_changed(
+	GtkSpinButton   *spinbutton,
+	gpointer         user_data)
 {
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
+
   /* Get new "incline" structure angle from spinbutton */
   structure_proj_params.Wi = gtk_spin_button_get_value(spinbutton);
-  New_Structure_Projection_Angle();
 
   /* Sync rad pattrern window spinbutton if enabled */
   if( isFlagSet(DRAW_ENABLED) && isFlagSet(COMMON_PROJECTION) )
 	gtk_spin_button_set_value(
 		incline_rdpattern, (gdouble)structure_proj_params.Wi );
+
+  New_Structure_Projection_Angle();
+  gtk_spin_button_update( spinbutton );
 }
 
 
@@ -450,7 +487,9 @@ on_main_freq_spinbutton_value_changed  (GtkSpinButton   *spinbutton,
 {
   static gdouble fmhz_save = 0.0;
 
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
 
   /* Frequency spinbutton value changed by frequency loop */
   if( isFlagSet(FREQ_LOOP_RUNNING) )
@@ -481,9 +520,12 @@ on_main_freq_spinbutton_value_changed  (GtkSpinButton   *spinbutton,
 	if( isFlagSet(DRAW_ENABLED) 	&&
 		isFlagSet(COMMON_FREQUENCY) &&
 		isFlagSet(MAIN_NEW_FREQ) )
+	  /* Show current frequency */
 	  gtk_spin_button_set_value( rdpattern_frequency, fmhz );
 
   } /* else */
+
+  gtk_spin_button_update( spinbutton );
 }
 
 
@@ -533,8 +575,27 @@ on_structure_drawingarea_motion_notify_event( GtkWidget       *widget,
 											  GdkEventMotion  *event,
 											  gpointer         user_data)
 {
-  Motion_Event( event, &structure_proj_params,
-	  rotate_structure, incline_structure );
+  /* Use only 1 in MOTION_EVENTS_COUNT event */
+  static int cnt = 0;
+  if( cnt++ < MOTION_EVENTS_COUNT )
+	return FALSE;
+  cnt = 0;
+
+  /* Block motion events */
+  g_signal_handler_block
+	( (gpointer)structure_drawingarea, structure_motion_handler );
+
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return FALSE;
+
+  /* Handle motion events */
+  Motion_Event( event, &structure_proj_params );
+
+  /* Unblock motion events */
+  g_signal_handler_unblock(
+	  (gpointer)structure_drawingarea, structure_motion_handler );
+
   return TRUE;
 }
 
@@ -569,7 +630,7 @@ on_filechooserdialog_response          (GtkDialog       *dialog,
 	/* Get filename of NEC2 input file */
 	filename =
 	  gtk_file_chooser_get_filename( GTK_FILE_CHOOSER(dialog) );
-	Strlcpy( infile, filename, strlen(filename)+1 ); /* For null term. */
+	Strlcpy( infile, filename, sizeof(infile) );
 	g_free( filename );
 	gtk_widget_destroy( file_chooser );
 
@@ -593,7 +654,8 @@ on_fileselection_response(  GtkDialog       *dialog,
   if( response_id == GTK_RESPONSE_OK )
   {
 	/* Get the "save as" file name */
-	Strlcpy( filename, gtk_file_selection_get_filename(
+	Strlcpy( filename,
+		gtk_file_selection_get_filename(
 		  GTK_FILE_SELECTION(dialog)), s );
 
 	if( isFlagSet(IMAGE_SAVE) )
@@ -614,7 +676,7 @@ on_fileselection_response(  GtkDialog       *dialog,
 		Strlcat( filename, ".nec", s );
 
 	  /* Use new file name as input file */
-	  Strlcpy( infile, filename, strlen(filename)+1 );
+	  Strlcpy( infile, filename, sizeof(infile) );
 	  Save_Nec2_Input_File( nec2_edit_window, filename );
 
 	  /* Re-open NEC2 input file */
@@ -678,6 +740,7 @@ on_freqplots_save_activate             (GtkMenuItem     *menuitem,
 										gpointer         user_data)
 {
   char saveas[96];
+  size_t s = sizeof( saveas );
   static int cnt = 0;
 
   if( (strlen(infile) == 0) || isFlagClear(PLOT_SELECT) )
@@ -685,9 +748,7 @@ on_freqplots_save_activate             (GtkMenuItem     *menuitem,
 
   /* Make file name from input file name,
    * to save frequency plots drawing */
-  snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "plots", ++cnt, "png" );
-  saveas[95] = '\0';
-
+  snprintf( saveas, s, "%s-%s_%03d.%s", infile, "plots", ++cnt, "png" );
   saveas_pixmap = freqplots_pixmap;
   saveas_pixmap_width  = freqplots_pixmap_width;
   saveas_pixmap_height = freqplots_pixmap_height;
@@ -772,11 +833,11 @@ void
 on_freqplots_zo_spinbutton_value_changed( GtkSpinButton   *spinbutton,
 										  gpointer         user_data)
 {
-  gtk_spin_button_update( spinbutton );
   /* Set the value of Z0 used for VSWR calculations */
   calc_data.zo = gtk_spin_button_get_value(spinbutton);
   if( isFlagSet(PLOT_ENABLED) )
 	Plot_Frequency_Data();
+  gtk_spin_button_update( spinbutton );
 }
 
 
@@ -833,6 +894,10 @@ on_freqplots_drawingarea_button_press_event(GtkWidget       *widget,
 											GdkEventButton  *event,
 											gpointer         user_data)
 {
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return FALSE;
+
   Set_Frequency_On_Click( event );
   return TRUE;
 }
@@ -862,6 +927,7 @@ on_rdpattern_save_activate             (GtkMenuItem     *menuitem,
 										gpointer         user_data)
 {
   char saveas[96];
+  size_t s = sizeof( saveas );
   static int cgn = 0, ceh = 0;;
 
   if( strlen(infile) == 0 )
@@ -870,11 +936,10 @@ on_rdpattern_save_activate             (GtkMenuItem     *menuitem,
   /* Make the rad pattern save
    * file name from input name */
   if( isFlagSet(DRAW_GAIN) )
-	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "gain", ++cgn, "png" );
+	snprintf( saveas, s, "%s-%s_%03d.%s", infile, "gain", ++cgn, "png" );
   else if( isFlagSet(DRAW_EHFIELD) )
-	snprintf( saveas, 95, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
+	snprintf( saveas, s, "%s-%s_%03d.%s", infile, "fields", ++ceh, "png" );
   else return;
-  saveas[95] = '\0';
 
   saveas_pixmap = rdpattern_pixmap;
   saveas_pixmap_width  = rdpattern_pixmap_width;
@@ -1017,6 +1082,9 @@ on_rdpattern_x_axis_clicked            (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 0.0, 0.0, rotate_rdpattern,
 	  incline_rdpattern, &rdpattern_proj_params );
+  if( isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 0.0, 0.0, rotate_structure,
+		incline_structure, &structure_proj_params );
 }
 
 
@@ -1027,6 +1095,9 @@ on_rdpattern_y_axis_clicked            (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 90.0, 0.0, rotate_rdpattern,
 	  incline_rdpattern, &rdpattern_proj_params );
+  if( isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 90.0, 0.0, rotate_structure,
+		incline_structure, &structure_proj_params );
 }
 
 
@@ -1037,52 +1108,67 @@ on_rdpattern_z_axis_clicked            (GtkButton       *button,
   /* Recalculate projection paramenters */
   New_Viewer_Angle( 0.0, 90.0, rotate_rdpattern,
 	  incline_rdpattern, &rdpattern_proj_params );
+  if( isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 0.0, 90.0, rotate_structure,
+		incline_structure, &structure_proj_params );
 }
 
 
   void
-on_rdpattern_default_view_clicked      (GtkButton       *button,
-										gpointer         user_data)
+on_rdpattern_default_view_clicked
+  (GtkButton       *button,
+  gpointer         user_data)
 {
   /* Projection at 45 deg rotation and inclination */
   New_Viewer_Angle( 45.0, 45.0, rotate_rdpattern,
 	  incline_rdpattern, &rdpattern_proj_params );
+  if( isFlagSet(COMMON_PROJECTION) )
+	New_Viewer_Angle( 45.0, 45.0, rotate_structure,
+		incline_structure, &structure_proj_params );
 }
 
 
 void
-on_rdpattern_rotate_spinbutton_value_changed(GtkSpinButton   *spinbutton,
-											  gpointer         user_data)
+on_rdpattern_rotate_spinbutton_value_changed(
+	GtkSpinButton   *spinbutton,
+	gpointer         user_data)
 {
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
 
   /* Get new value of "rotate pattern" angle from spinbutton */
   rdpattern_proj_params.Wr = gtk_spin_button_get_value(spinbutton);
-  New_Radiation_Projection_Angle();
 
   /* Sync main window rotate spinbutton */
   if( isFlagSet(COMMON_PROJECTION) )
-	gtk_spin_button_set_value( GTK_SPIN_BUTTON(lookup_widget(
-			main_window, "main_rotate_spinbutton")),
-		(gdouble)rdpattern_proj_params.Wr );
+	gtk_spin_button_set_value(
+		rotate_structure, (gdouble)rdpattern_proj_params.Wr );
+
+  New_Radiation_Projection_Angle();
+  gtk_spin_button_update( spinbutton );
 }
 
 
 void
-on_rdpattern_incline_spinbutton_value_changed(GtkSpinButton   *spinbutton,
-											  gpointer         user_data)
+on_rdpattern_incline_spinbutton_value_changed(
+	GtkSpinButton   *spinbutton,
+	gpointer         user_data)
 {
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
 
   /* Get new value of "incline pattern" angle from spinbutton */
   rdpattern_proj_params.Wi = gtk_spin_button_get_value(spinbutton);
-  New_Radiation_Projection_Angle();
 
   /* Sync main window incline spinbutton */
   if( isFlagSet(COMMON_PROJECTION) )
-	gtk_spin_button_set_value( GTK_SPIN_BUTTON(lookup_widget(
-			main_window, "main_incline_spinbutton")),
-		(gdouble)rdpattern_proj_params.Wi );
+	gtk_spin_button_set_value(
+		incline_structure, (gdouble)rdpattern_proj_params.Wi );
+
+  New_Radiation_Projection_Angle();
+  gtk_spin_button_update( spinbutton );
 }
 
 
@@ -1137,7 +1223,9 @@ on_rdpattern_freq_spinbutton_value_changed(	GtkSpinButton   *spinbutton,
 {
   static gdouble fmhz_save = 0.0;
 
-  gtk_spin_button_update( spinbutton );
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return;
 
   /* Frequency spinbutton value changed by frequency loop */
   if( isFlagSet(FREQ_LOOP_RUNNING) && isFlagSet(DRAW_ENABLED) )
@@ -1165,6 +1253,7 @@ on_rdpattern_freq_spinbutton_value_changed(	GtkSpinButton   *spinbutton,
 	if( isFlagSet(COMMON_FREQUENCY) )
 	  gtk_spin_button_set_value( mainwin_frequency, fmhz );
   } /* else */
+  gtk_spin_button_update( spinbutton );
 }
 
 
@@ -1217,8 +1306,27 @@ on_rdpattern_drawingarea_motion_notify_event( GtkWidget       *widget,
 											  GdkEventMotion  *event,
 											  gpointer         user_data)
 {
-  Motion_Event( event, &rdpattern_proj_params,
-	  rotate_rdpattern, incline_rdpattern );
+  /* Use only 1 in MOTION_EVENTS_COUNT event */
+  static int cnt = 0;
+  if( cnt++ < MOTION_EVENTS_COUNT )
+	return FALSE;
+  cnt = 0;
+
+  /* Block motion events */
+  g_signal_handler_block(
+	  (gpointer)rdpattern_drawingarea, rdpattern_motion_handler );
+
+  /* No redraws if new input pending */
+  if( isFlagSet(INPUT_PENDING) )
+	return FALSE;
+
+  /* Handle motion events */
+  Motion_Event( event, &rdpattern_proj_params );
+
+  /* Unblock motion events */
+  g_signal_handler_unblock(
+	  (gpointer)rdpattern_drawingarea, rdpattern_motion_handler );
+
   return TRUE;
 }
 
@@ -1427,7 +1535,7 @@ on_animation_applybutton_clicked       (GtkButton       *button,
 		"animate_steps_spinbutton") );
   steps = gtk_spin_button_get_value( spinbutton );
   intval = (guint)(1000.0 / steps / freq);
-  near_field.anim_step = (double)TP / steps;
+  near_field.anim_step = (double)TWOPI / steps;
 
   SetFlag( NEAREH_ANIMATE );
   if( anim_tag > 0 )
@@ -1461,7 +1569,7 @@ on_animation_okbutton_clicked          (GtkButton       *button,
 		"animate_steps_spinbutton") );
   steps = gtk_spin_button_get_value( spinbutton );
   intval = (guint)(1000.0 / steps / freq);
-  near_field.anim_step = (double)TP / steps;
+  near_field.anim_step = (double)TWOPI / steps;
 
   SetFlag( NEAREH_ANIMATE );
   if( anim_tag > 0 )
@@ -1662,28 +1770,33 @@ on_nec2_row_remv_clicked               (GtkButton       *button,
   gtk_tree_selection_get_selected( selection, &model, &iter);
   gtk_list_store_remove( GTK_LIST_STORE(model), &iter );
   selected_treeview = NULL;
+  SetFlag( EDITOR_QUIT );
 }
 
 
-void
+  void
 on_nec2_treeview_clear_clicked         (GtkButton       *button,
-                                        gpointer         user_data)
+										gpointer         user_data)
 {
   if( selected_treeview != NULL )
+  {
+
 	gtk_list_store_clear( GTK_LIST_STORE(
 		  gtk_tree_view_get_model(selected_treeview)) );
+	SetFlag( EDITOR_QUIT );
+  }
 }
 
 
 gboolean
-on_nec2_cmnt_treeview_button_press_event
-                                        (GtkWidget       *widget,
+  on_nec2_cmnt_treeview_button_press_event
+                                        (GtkWidget      *widget,
                                         GdkEventButton  *event,
                                         gpointer         user_data)
 {
   selected_treeview = GTK_TREE_VIEW(widget);
   if( event->button == 3 )
-	Open_Editor(selected_treeview);
+	Open_Editor( selected_treeview );
   return FALSE;
 }
 
@@ -1698,7 +1811,7 @@ on_nec2_geom_treeview_button_press_event
   if( event->button == 3 )
   {
 	action = EDITOR_EDIT;
-	Open_Editor(selected_treeview);
+	Open_Editor( selected_treeview );
 	action = EDITOR_NEW;
   }
   return FALSE;
@@ -1885,7 +1998,10 @@ on_gw_clicked                          (GtkButton       *button,
 	wire_editor = create_wire_editor();
 	gtk_widget_hide( lookup_widget(wire_editor, "wire_taperframe") );
 	gtk_widget_show( wire_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Wire_Editor( EDITOR_APPLY );
+
   Wire_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1899,7 +2015,10 @@ on_ga_clicked                          (GtkButton       *button,
   {
 	arc_editor = create_arc_editor();
 	gtk_widget_show( arc_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Arc_Editor( EDITOR_APPLY );
+
   Arc_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1913,7 +2032,10 @@ on_gh_clicked                          (GtkButton       *button,
   {
 	helix_editor = create_helix_editor();
 	gtk_widget_show( helix_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Helix_Editor( EDITOR_APPLY );
+
   Helix_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1927,7 +2049,10 @@ on_sp_clicked                          (GtkButton       *button,
   {
 	patch_editor = create_patch_editor();
 	gtk_widget_show( patch_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Patch_Editor( EDITOR_APPLY );
+
   Patch_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1941,7 +2066,10 @@ on_gr_clicked                          (GtkButton       *button,
   {
 	cylinder_editor = create_cylinder_editor();
 	gtk_widget_show( cylinder_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Cylinder_Editor( EDITOR_APPLY );
+
   Cylinder_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1955,7 +2083,10 @@ on_gm_clicked                          (GtkButton       *button,
   {
 	transform_editor = create_transform_editor();
 	gtk_widget_show( transform_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Transform_Editor( EDITOR_APPLY );
+
   Transform_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1969,7 +2100,10 @@ on_gx_clicked                          (GtkButton       *button,
   {
 	reflect_editor = create_reflect_editor();
 	gtk_widget_show( reflect_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Reflect_Editor( EDITOR_APPLY );
+
   Reflect_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1983,7 +2117,10 @@ on_gs_clicked                          (GtkButton       *button,
   {
 	scale_editor = create_scale_editor();
 	gtk_widget_show( scale_editor );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Scale_Editor( EDITOR_APPLY );
+
   Scale_Editor( action );
   action = EDITOR_NEW;
 }
@@ -1997,7 +2134,10 @@ on_ex_clicked                          (GtkButton       *button,
   {
 	excitation_command = create_excitation_command();
 	gtk_widget_show( excitation_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Excitation_Command( EDITOR_APPLY );
+
   Excitation_Command( action );
   action = EDITOR_NEW;
 }
@@ -2011,7 +2151,10 @@ on_fr_clicked                          (GtkButton       *button,
   {
 	frequency_command = create_frequency_command();
 	gtk_widget_show( frequency_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Frequency_Command( EDITOR_APPLY );
+
   Frequency_Command( action );
   action = EDITOR_NEW;
 }
@@ -2025,7 +2168,10 @@ on_gn_clicked                          (GtkButton       *button,
   {
 	ground_command = create_ground_command();
 	gtk_widget_show( ground_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Ground_Command( EDITOR_APPLY );
+
   Ground_Command( action );
   action = EDITOR_NEW;
 }
@@ -2039,7 +2185,10 @@ on_gd_clicked                          (GtkButton       *button,
   {
 	ground2_command = create_ground2_command();
 	gtk_widget_show( ground2_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Ground2_Command( EDITOR_APPLY );
+
   Ground2_Command( action );
   action = EDITOR_NEW;
 }
@@ -2053,7 +2202,10 @@ on_rp_clicked                          (GtkButton       *button,
   {
 	radiation_command = create_radiation_command();
 	gtk_widget_show( radiation_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Radiation_Command( EDITOR_APPLY );
+
   Radiation_Command( action );
   action = EDITOR_NEW;
 }
@@ -2067,7 +2219,10 @@ on_ld_clicked                          (GtkButton       *button,
   {
 	loading_command = create_loading_command();
 	gtk_widget_show( loading_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Loading_Command( EDITOR_APPLY );
+
   Loading_Command( action );
   action = EDITOR_NEW;
 }
@@ -2081,7 +2236,10 @@ on_nt_clicked                          (GtkButton       *button,
   {
 	network_command = create_network_command();
 	gtk_widget_show( network_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Network_Command( EDITOR_APPLY );
+
   Network_Command( action );
   action = EDITOR_NEW;
 }
@@ -2095,7 +2253,10 @@ on_tl_clicked                          (GtkButton       *button,
   {
 	txline_command = create_txline_command();
 	gtk_widget_show( txline_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Txline_Command( EDITOR_APPLY );
+
   Txline_Command( action );
   action = EDITOR_NEW;
 }
@@ -2109,7 +2270,10 @@ on_ne_clicked                          (GtkButton       *button,
   {
 	nearfield_command = create_nearfield_command();
 	gtk_widget_show( nearfield_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Nearfield_Command( EDITOR_APPLY );
+
   Nearfield_Command( action );
   action = EDITOR_NEW;
 }
@@ -2123,7 +2287,10 @@ on_ek_clicked                          (GtkButton       *button,
   {
 	kernel_command = create_kernel_command();
 	gtk_widget_show( kernel_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Kernel_Command( EDITOR_APPLY );
+
   Kernel_Command( action );
   action = EDITOR_NEW;
 }
@@ -2137,7 +2304,10 @@ on_kh_clicked                          (GtkButton       *button,
   {
 	intrange_command = create_intrange_command();
 	gtk_widget_show( intrange_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Intrange_Command( EDITOR_APPLY );
+
   Intrange_Command( action );
   action = EDITOR_NEW;
 }
@@ -2151,7 +2321,10 @@ on_xq_clicked                          (GtkButton       *button,
   {
 	execute_command = create_execute_command();
 	gtk_widget_show( execute_command );
+	ClearFlag( EDITOR_QUIT );
   }
+  else Execute_Command( EDITOR_APPLY );
+
   Execute_Command( action );
   action = EDITOR_NEW;
 }
@@ -3550,10 +3723,10 @@ on_structure_plus_button_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
   structure_proj_params.xy_zoom =
-	gtk_spin_button_get_value( structure_zoom_spinbutton );
+	gtk_spin_button_get_value( structure_zoom );
   structure_proj_params.xy_zoom *= 1.1;
   gtk_spin_button_set_value(
-	  structure_zoom_spinbutton, structure_proj_params.xy_zoom );
+	  structure_zoom, structure_proj_params.xy_zoom );
 }
 
 
@@ -3562,10 +3735,10 @@ on_structure_minus_button_clicked      (GtkButton       *button,
                                         gpointer         user_data)
 {
   structure_proj_params.xy_zoom =
-	gtk_spin_button_get_value( structure_zoom_spinbutton );
+	gtk_spin_button_get_value( structure_zoom );
   structure_proj_params.xy_zoom /= 1.1;
   gtk_spin_button_set_value(
-	  structure_zoom_spinbutton, structure_proj_params.xy_zoom );
+	  structure_zoom, structure_proj_params.xy_zoom );
 }
 
 
@@ -3573,7 +3746,7 @@ void
 on_structure_one_button_clicked        (GtkButton       *button,
                                         gpointer         user_data)
 {
-  gtk_spin_button_set_value( structure_zoom_spinbutton, 100.0 );
+  gtk_spin_button_set_value( structure_zoom, 100.0 );
   structure_proj_params.reset = TRUE;
   New_Projection_Parameters(
 	  structure_pixmap_width,
@@ -3614,10 +3787,10 @@ on_rdpattern_plus_button_clicked       (GtkButton       *button,
                                         gpointer         user_data)
 {
   rdpattern_proj_params.xy_zoom =
-	gtk_spin_button_get_value( rdpattern_zoom_spinbutton );
+	gtk_spin_button_get_value( rdpattern_zoom );
   rdpattern_proj_params.xy_zoom *= 1.1;
   gtk_spin_button_set_value(
-	  rdpattern_zoom_spinbutton, rdpattern_proj_params.xy_zoom );
+	  rdpattern_zoom, rdpattern_proj_params.xy_zoom );
 }
 
 
@@ -3626,10 +3799,10 @@ on_rdpattern_minus_button_clicked      (GtkButton       *button,
                                         gpointer         user_data)
 {
   rdpattern_proj_params.xy_zoom =
-	gtk_spin_button_get_value( rdpattern_zoom_spinbutton );
+	gtk_spin_button_get_value( rdpattern_zoom );
   rdpattern_proj_params.xy_zoom /= 1.1;
   gtk_spin_button_set_value(
-	  rdpattern_zoom_spinbutton, rdpattern_proj_params.xy_zoom );
+	  rdpattern_zoom, rdpattern_proj_params.xy_zoom );
 }
 
 
@@ -3637,7 +3810,7 @@ void
 on_rdpattern_one_button_clicked        (GtkButton       *button,
                                         gpointer         user_data)
 {
-  gtk_spin_button_set_value( rdpattern_zoom_spinbutton, 100.0 );
+  gtk_spin_button_set_value( rdpattern_zoom, 100.0 );
   rdpattern_proj_params.reset = TRUE;
   New_Projection_Parameters(
 	  rdpattern_pixmap_width,
@@ -3653,13 +3826,13 @@ on_structure_drawingarea_scroll_event  (GtkWidget       *widget,
 										gpointer         user_data)
 {
   structure_proj_params.xy_zoom =
-	gtk_spin_button_get_value( structure_zoom_spinbutton );
+	gtk_spin_button_get_value( structure_zoom );
   if( event->scroll.direction == GDK_SCROLL_UP )
 	structure_proj_params.xy_zoom *= 1.1;
   else if( event->scroll.direction == GDK_SCROLL_DOWN )
 	structure_proj_params.xy_zoom /= 1.1;
   gtk_spin_button_set_value(
-	  structure_zoom_spinbutton, structure_proj_params.xy_zoom );
+	  structure_zoom, structure_proj_params.xy_zoom );
   return FALSE;
 }
 
@@ -3670,13 +3843,13 @@ on_rdpattern_drawingarea_scroll_event  (GtkWidget       *widget,
                                         gpointer         user_data)
 {
   rdpattern_proj_params.xy_zoom =
-	gtk_spin_button_get_value( rdpattern_zoom_spinbutton );
+	gtk_spin_button_get_value( rdpattern_zoom );
   if( event->scroll.direction == GDK_SCROLL_UP )
 	rdpattern_proj_params.xy_zoom *= 1.1;
   else if( event->scroll.direction == GDK_SCROLL_DOWN )
 	rdpattern_proj_params.xy_zoom /= 1.1;
   gtk_spin_button_set_value(
-	  rdpattern_zoom_spinbutton, rdpattern_proj_params.xy_zoom );
+	  rdpattern_zoom, rdpattern_proj_params.xy_zoom );
   return FALSE;
 }
 
