@@ -46,10 +46,10 @@
 
 /* common constants */
 #define PI		3.141592654
-#define	POT		1.570796327
-#define	TP		6.283185308
-#define	TA		1.745329252E-02
-#define	TD		57.29577951
+#define	PITWO	1.570796327
+#define	TWOPI	6.283185308
+#define	TORAD	1.745329252E-02
+#define	TODEG	57.29577951
 #define	ETA		376.73
 #define	CVEL	299.8
 #define	CONST1	(0.0+I*4.771341189)
@@ -65,6 +65,9 @@
 /* Max length of a line read from input file */
 #define	LINE_LEN	135
 
+/* Size of char arrays (strings) for error messages etc */
+#define MESG_SIZE	128
+
 /* Type of projection parameters stuct */
 #define	STRUCTURE_DRAWINGAREA	1
 #define	RDPATTERN_DRAWINGAREA	2
@@ -161,6 +164,9 @@
 #define	ALLOC_RDPAT_BUFF	0x0000200000000000ll
 #define	ALLOC_PNTING_BUFF	0x0000400000000000ll
 
+/* Force editors to quit */
+#define	EDITOR_QUIT			0x0000800000000000ll
+
 #define	ALL_FLAGS		    0xffffffffffffffffll
 
 /* Type of near field data requested */
@@ -700,8 +706,9 @@ void zint(double sigl, double rolam, _Complex double *zint);
 /* callback_func.c */
 void Save_Pixmap(GdkPixmap *pixmap, int pixmap_width, int pixmap_height, char *filename);
 void New_Viewer_Angle(double wr, double wi, GtkSpinButton *wr_spb, GtkSpinButton *wi_spb, projection_parameters_t *params);
+void Set_Spin_Button(GtkSpinButton *spin, gdouble value);
 void Create_Pixmap(GdkPixmap **pixmap, int *pixmap_width, int *pixmap_height, GtkWidget *widget, GdkEventConfigure *event, projection_parameters_t *params);
-void Motion_Event(GdkEventMotion *event, projection_parameters_t *params, GtkSpinButton *wr_spb, GtkSpinButton *wi_spb);
+void Motion_Event(GdkEventMotion *event, projection_parameters_t *params);
 void Plot_Select(GtkToggleButton *togglebutton, unsigned long long int flag);
 void Delete_Event(gchar *message);
 void Set_Pol_Menuitem(GtkMenuItem *menuitem);
@@ -1283,7 +1290,7 @@ void ToggleFlag(unsigned long long int flag);
 void SaveFlag(unsigned long long int *flag, unsigned long long int mask);
 void Strlcpy(char *dest, const char *src, size_t n);
 void Strlcat(char *dest, const char *src, size_t n);
-double Strtod(const char *nptr, char **endptr);
+double Strtod(char *nptr, char **endptr);
 /* xnec2c.c */
 void Frequency_Scale_Geometry(void);
 void Structure_Impedance_Loading(void);
