@@ -40,10 +40,6 @@ static point_3d_t *point_3d = NULL;
   void
 Draw_Radiation( GtkWidget *drawingarea )
 {
-  /* Block motion events */
-  g_signal_handler_block(
-	  (gpointer)drawingarea, rdpattern_motion_handler );
-
   /* Abort if xnec2c may be quit by user */
   if( isFlagSet(MAIN_QUIT) || isFlagClear(ENABLE_EXCITN) )
 	return;
@@ -77,11 +73,6 @@ Draw_Radiation( GtkWidget *drawingarea )
   while( g_main_context_iteration(NULL, FALSE) );
 
   cairo_destroy( cr );
-
-  /* Unblock motion events */
-  g_signal_handler_unblock(
-	  (gpointer)drawingarea, rdpattern_motion_handler );
-
 } /* Draw_Radiation() */
 
 /*-----------------------------------------------------------------------*/
@@ -103,6 +94,7 @@ Draw_Radiation_Pattern( void )
   GdkSegment segm;
 
   int
+	idx,
 	nth,     /* Theta step count */
 	nph,     /* Phi step count   */
 	col_idx, /* Index to rad pattern color buffers */
@@ -117,8 +109,8 @@ Draw_Radiation_Pattern( void )
   double theta, phi, r, r_min, r_range;
 
   /* theta and phi step in rads */
-  double dth = (double)fpat.dth * (double)TA;
-  double dph = (double)fpat.dph * (double)TA;
+  double dth = (double)fpat.dth * (double)TORAD;
+  double dph = (double)fpat.dph * (double)TORAD;
 
   /* Used to set text in labels */
   gchar txt[7];
@@ -133,24 +125,24 @@ Draw_Radiation_Pattern( void )
   if( isFlagSet(DRAW_NEW_RDPAT) )
   {
 	size_t mreq = ((size_t)(fpat.nth * fpat.nph)) * sizeof(point_3d_t);
-	mem_realloc( (void *)&point_3d, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&point_3d, mreq, "in draw_radiation.c" );
 	mreq = (size_t)((fpat.nth-1) * fpat.nph + (fpat.nph-1) * fpat.nth);
 	mreq *= sizeof(double);
-	mem_realloc( (void *)&red, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&grn, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&blu, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&red, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&grn, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&blu, mreq, "in draw_radiation.c" );
 
 	ClearFlag( DRAW_NEW_RDPAT );
 
 	/* Distance of rdpattern point furthest from xyz origin */
+	idx = rad_pattern[fstep].max_gain_idx[pol];
 	rdpattern_proj_params.r_max = Scale_Gain(
-		rad_pattern[fstep].gtot[rad_pattern[fstep].max_gain_idx[pol]],
-		fstep, rad_pattern[fstep].max_gain_idx[pol]);
+		rad_pattern[fstep].gtot[idx], fstep, idx);
 
 	/* Distance of rdpattern point nearest to xyz origin */
+	idx = rad_pattern[fstep].min_gain_idx[pol];
 	r_min = Scale_Gain(
-		rad_pattern[fstep].gtot[rad_pattern[fstep].min_gain_idx[pol]],
-		fstep, rad_pattern[fstep].min_gain_idx[pol]);
+		rad_pattern[fstep].gtot[idx], fstep, idx);
 
 	/* Range of scaled rdpattern gain values */
 	r_range = rdpattern_proj_params.r_max - r_min;
@@ -164,12 +156,12 @@ Draw_Radiation_Pattern( void )
 	/*** Convert radiation pattern values
 	 * to points in 3d space in x,y,z axis ***/
 	pts_idx = 0;
-	phi = (double)(fpat.phis * TA); /* In rads */
+	phi = (double)(fpat.phis * TORAD); /* In rads */
 
 	/* Step phi angle */
 	for( nph = 0; nph < fpat.nph; nph++ )
 	{
-	  theta = (double)(fpat.thets * TA); /* In rads */
+	  theta = (double)(fpat.thets * TORAD); /* In rads */
 
 	  /* Step theta angle */
 	  for( nth = 0; nth < fpat.nth; nth++ )
@@ -243,14 +235,12 @@ Draw_Radiation_Pattern( void )
 
 	/* Show max gain on color code bar */
 	snprintf( txt, 7, "%6f", rad_pattern[fstep].max_gain[pol] );
-	txt[6] = '\0';
 	gtk_label_set_text(
 		GTK_LABEL(lookup_widget(rdpattern_window,
 			"rdpattern_colorcode_maxlabel")), txt );
 
 	/* Show min gain on color code bar */
 	snprintf( txt, 5, "%4f", rad_pattern[fstep].min_gain[pol] );
-	txt[6] = '\0';
 	gtk_label_set_text(
 		GTK_LABEL(lookup_widget(rdpattern_window,
 			"rdpattern_colorcode_minlabel")), txt );
@@ -520,10 +510,10 @@ Draw_Near_Field( void )
 	  if( isFlagSet(ALLOC_PNTING_BUFF) )
 	  {
 		size_t mreq = (size_t)npts * sizeof( double );
-		mem_realloc( (void *)&pov_x, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_y, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_z, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_r, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
 		ClearFlag( ALLOC_PNTING_BUFF );
 	  }
 
@@ -592,7 +582,7 @@ Draw_Near_Field( void )
   else if( isFlagSet(DRAW_POYNTING) )
 	max = pov_max;
 
-  snprintf( txt, 9, "%8.2E", max );
+  snprintf( txt, sizeof(txt), "%8.2E", max );
   gtk_label_set_text(
 	  GTK_LABEL(lookup_widget(rdpattern_window,
 		  "rdpattern_colorcode_maxlabel")), txt );
@@ -661,7 +651,7 @@ Animate_Near_Field( gpointer udata )
 
   /* Increment excitation phase, keep < 2pi */
   wt += near_field.anim_step;
-  if( wt >= (double)TP )
+  if( wt >= (double)TWOPI )
 	wt = 0.0;
 
   Draw_Radiation( rdpattern_drawingarea );
@@ -683,12 +673,9 @@ static int gain_style = GS_LINP;
 Scale_Gain( double gain, int fstep, int idx )
 {
   /* Scaled rad pattern gain and pol factor */
-  double scaled_rad = 0.0, polf;
+  double scaled_rad = 0.0;
 
-  polf = Polarization_Factor( calc_data.pol_type, fstep, idx );
-  if ( polf< 1e-200 ) return( 0.0 );
-
-  gain += 10.0 * log10(polf);
+  gain += Polarization_Factor( calc_data.pol_type, fstep, idx );
 
   switch( gain_style )
   {
@@ -763,8 +750,10 @@ Polarization_Factor( int pol_type, int fstep, int idx )
 	  polf  = (1.0 - 2.0 * axrt + axrt2) / 2.0 / (1.0 + axrt2);
   }
 
+  if( polf < 1.0E-200 ) polf = 1.0E-200;
+  polf = 10.0 * log10( polf );
+  
   return( polf );
-
 } /* Polarization_Factor() */
 
 /*-----------------------------------------------------------------------*/
@@ -831,10 +820,10 @@ Set_Gain_Style( int gs )
 New_Radiation_Projection_Angle(void)
 {
   /* sin and cos of rad pattern rotation and inclination angles */
-  rdpattern_proj_params.sin_wr = sin(rdpattern_proj_params.Wr/(double)TD);
-  rdpattern_proj_params.cos_wr = cos(rdpattern_proj_params.Wr/(double)TD);
-  rdpattern_proj_params.sin_wi = sin(rdpattern_proj_params.Wi/(double)TD);
-  rdpattern_proj_params.cos_wi = cos(rdpattern_proj_params.Wi/(double)TD);
+  rdpattern_proj_params.sin_wr = sin(rdpattern_proj_params.Wr/(double)TODEG);
+  rdpattern_proj_params.cos_wr = cos(rdpattern_proj_params.Wr/(double)TODEG);
+  rdpattern_proj_params.sin_wi = sin(rdpattern_proj_params.Wi/(double)TODEG);
+  rdpattern_proj_params.cos_wi = cos(rdpattern_proj_params.Wi/(double)TODEG);
 
   /* Trigger a redraw of radiation drawingarea */
   if( isFlagSet(DRAW_ENABLED) )
@@ -880,41 +869,43 @@ Viewer_Gain( projection_parameters_t proj_parameters, int fstep )
 {
   double phi, gain;
   int nth, nph, idx;
-
-
+  
   /* Calculate theta step from proj params */
   phi = proj_parameters.Wr;
-  if( fpat.dth == 0.0 )
-	nth = 0;
+  if( fpat.dth == 0.0 ) nth = 0;
   else
   {
-	double theta = fabs( 90.0 - proj_parameters.Wi );
+	double theta;
+	theta = fabs( 90.0 - proj_parameters.Wi );
 	if( theta > 180.0 )
 	{
 	  theta = 360.0 - theta;
 	  phi  -= 180.0;
 	}
-	if( (gnd.ksymp == 2) && (theta > 90.01) && (gnd.ifar != 1) )
+
+	if( (gnd.ksymp == 2) &&
+		(theta > 90.01)  &&
+		(gnd.ifar != 1) )
 	  return( -999.99 );
-	nth = (int)( theta/fpat.dth + 0.5 );
+
+	nth = (int)( (theta - fpat.thets) / fpat.dth + 0.5 );
 	if( (nth >= fpat.nth) || (nth < 0) )
 	  nth = fpat.nth-1;
   }
 
   /* Calculate phi step from proj params */
-  if( fpat.dph == 0.0 )
-	nph = 0;
+  if( fpat.dph == 0.0 ) nph = 0;
   else
   {
 	while( phi < 0.0 ) phi += 360.0;
-	nph = (int)( phi/fpat.dph + 0.5 );
+	nph = (int)( (phi - fpat.phis) / fpat.dph + 0.5 );
 	if( (nph >= fpat.nph) || (nph < 0) )
 	  nph = fpat.nph-1;
   }
 
-  idx = nth + nph*fpat.nth;
+  idx = nth + nph * fpat.nth;
   gain = rad_pattern[fstep].gtot[idx] +
-		10.0 * log10( Polarization_Factor(calc_data.pol_type, fstep, idx) );
+		Polarization_Factor(calc_data.pol_type, fstep, idx);
   if( gain < -999.99 ) gain = -999.99;
 
   return( gain );
@@ -1036,53 +1027,52 @@ Alloc_Rdpattern_Buffers( int nfrq, int nth, int nph )
   /* Free old gain buffers first */
   for( idx = 0; idx < last_nfrq; idx++ )
   {
-	free_ptr( (void *)&rad_pattern[idx].gtot );
-	free_ptr( (void *)&rad_pattern[idx].max_gain );
-	free_ptr( (void *)&rad_pattern[idx].min_gain );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_tht );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_phi );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_idx );
-	free_ptr( (void *)&rad_pattern[idx].min_gain_idx );
-	free_ptr( (void *)&rad_pattern[idx].axrt );
-	free_ptr( (void *)&rad_pattern[idx].tilt );
-	free_ptr( (void *)&rad_pattern[idx].sens );
+	free_ptr( (void **)&rad_pattern[idx].gtot );
+	free_ptr( (void **)&rad_pattern[idx].max_gain );
+	free_ptr( (void **)&rad_pattern[idx].min_gain );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_tht );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_phi );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_idx );
+	free_ptr( (void **)&rad_pattern[idx].min_gain_idx );
+	free_ptr( (void **)&rad_pattern[idx].axrt );
+	free_ptr( (void **)&rad_pattern[idx].tilt );
+	free_ptr( (void **)&rad_pattern[idx].sens );
   }
   last_nfrq = nfrq;
 
   /* Allocate rad pattern buffers */
   mreq = (size_t)nfrq * sizeof(rad_pattern_t);
-  mem_realloc( (void *)&rad_pattern, mreq, "in draw_radiation.c" );
-
+  mem_realloc( (void **)&rad_pattern, mreq, "in draw_radiation.c" );
   for( idx = 0; idx < nfrq; idx++ )
   {
 	/* Memory request for allocs */
 	mreq = (size_t)(nph * nth) * sizeof(double);
 	rad_pattern[idx].gtot = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].gtot, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].gtot), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].axrt = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].axrt, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].axrt), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].tilt = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].tilt, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].tilt), mreq, "in draw_radiation.c" );
 
 	mreq = NUM_POL * sizeof(double);
 	rad_pattern[idx].max_gain = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].min_gain = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].min_gain, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].min_gain), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].max_gain_tht = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_tht, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_tht), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].max_gain_phi = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_phi, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_phi), mreq, "in draw_radiation.c" );
 
 	mreq = NUM_POL * sizeof(int);
 	rad_pattern[idx].max_gain_idx = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_idx, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_idx), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].min_gain_idx = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].min_gain_idx, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].min_gain_idx), mreq, "in draw_radiation.c" );
 
 	rad_pattern[idx].sens = NULL;
 	mreq = (size_t)(nph * nth) * sizeof(int);
-	mem_alloc( (void *)&rad_pattern[idx].sens, mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].sens), mreq, "in draw_radiation.c" );
   }
 
 } /* Alloc_Rdpattern_Buffers() */
@@ -1107,35 +1097,35 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   /* Allocate near field buffers */
   if( fpat.nfeh & NEAR_EFIELD )
   {
-	mem_realloc( (void *)&near_field.ex,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ey,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ez,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fex, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fey, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fez, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.erx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ery, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.erz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.er,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ex,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ey,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ez,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fex, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fey, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fez, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.erx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ery, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.erz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.er,  mreq, "in draw_radiation.c" );
   }
 
   if( fpat.nfeh & NEAR_HFIELD )
   {
-	mem_realloc( (void *)&near_field.hx,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hy,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hz,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhy, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hrx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hry, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hrz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hr,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hx,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hy,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hz,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhy, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hrx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hry, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hrz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hr,  mreq, "in draw_radiation.c" );
   }
 
-  mem_realloc( (void *)&near_field.px, mreq, "in draw_radiation.c" );
-  mem_realloc( (void *)&near_field.py, mreq, "in draw_radiation.c" );
-  mem_realloc( (void *)&near_field.pz, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.px, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.py, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.pz, mreq, "in draw_radiation.c" );
 
 } /* Alloc_Nearfield_Buffers() */
 
@@ -1148,10 +1138,10 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   void
 Free_Draw_Buffers( void )
 {
-  free_ptr( (void *)&point_3d );
-  free_ptr( (void *)&red );
-  free_ptr( (void *)&grn );
-  free_ptr( (void *)&blu );
+  free_ptr( (void **)&point_3d );
+  free_ptr( (void **)&red );
+  free_ptr( (void **)&grn );
+  free_ptr( (void **)&blu );
 }
 
 /*-----------------------------------------------------------------------*/
