@@ -75,20 +75,20 @@ arc( int itg, int ns, double rada,
 
 	/* Reallocate tags buffer */
 	mreq = (size_t)(data.n + data.m) * sizeof(int);
-	mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
 	/* Reallocate wire buffers */
 	mreq = (size_t)data.n * sizeof(double);
-	mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
-	ang= ang1* TA;
-	dang=( ang2- ang1)* TA/ ns;
+	ang= ang1* TORAD;
+	dang=( ang2- ang1)* TORAD/ ns;
 	xs1= rada* cos( ang);
 	zs1= rada* sin( ang);
 
@@ -168,8 +168,8 @@ conect( int ignd )
   {
 	/* Allocate memory to connections */
 	mreq = (size_t)(data.n + data.m) * sizeof(int);
-	mem_realloc( (void *)&data.icon1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.icon2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.icon1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.icon2, mreq, "in geometry.c" );
 
 	for( i = 0; i < data.n; i++ )
 	{
@@ -367,7 +367,7 @@ conect( int ignd )
 
   /* Allocate to connection buffers */
   mreq = (size_t)segj.maxcon * sizeof(int);
-  mem_realloc( (void *)&segj.jco, mreq, "in geometry.c" );
+  mem_realloc( (void **)&segj.jco, mreq, "in geometry.c" );
 
   /* Adjust connected segment ends to exactly coincide.
    * Also find old seg. connecting to new segment */
@@ -412,7 +412,7 @@ conect( int ignd )
 		  {
 			segj.maxcon = ic+1;
 			mreq = (size_t)segj.maxcon * sizeof(int);
-			mem_realloc( (void *)&segj.jco, mreq, "in geometry.c" );
+			mem_realloc( (void **)&segj.jco, mreq, "in geometry.c" );
 		  }
 		  segj.jco[ic-1]= ix* jend;
 
@@ -494,9 +494,9 @@ conect( int ignd )
   } /* for( j = 0; j < data.n; j++ ) */
 
   mreq = (size_t)segj.maxcon * sizeof(double);
-  mem_realloc( (void *)&segj.ax, mreq, "in geometry.c" );
-  mem_realloc( (void *)&segj.bx, mreq, "in geometry.c" );
-  mem_realloc( (void *)&segj.cx, mreq, "in geometry.c" );
+  mem_realloc( (void **)&segj.ax, mreq, "in geometry.c" );
+  mem_realloc( (void **)&segj.bx, mreq, "in geometry.c" );
+  mem_realloc( (void **)&segj.cx, mreq, "in geometry.c" );
 
   return( TRUE );
 }
@@ -528,17 +528,17 @@ helix(
 
   /* Reallocate tags buffer */
   mreq = (size_t)data.n * sizeof(int);
-  mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
   /* Reallocate wire buffers */
   mreq = (size_t)data.n * sizeof(double);
-  mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
   data.z1[ist] = 0.0;
   for( i = ist; i < data.n; i++ )
@@ -699,17 +699,17 @@ move( double rox, double roy,
 	  k= data.n;
 	  /* Reallocate tags buffer */
 	  mreq = (size_t)(data.n + data.m + (data.n + 1 - i1) * nrpt) * sizeof(int);
-	  mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
 	  /* Reallocate wire buffers */
 	  mreq = (size_t)(data.n + (data.n + 1 - i1) * nrpt) * sizeof(double);
-	  mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 	}
 
 	for( ir = 0; ir < nrp; ir++ )
@@ -753,17 +753,17 @@ move( double rox, double roy,
 
 	/* Reallocate patch buffers */
 	mreq = (size_t)(data.m * (nrpt + 1)) * sizeof(double);
-	mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
 	for( ii = 0; ii < nrp; ii++ )
 	{
@@ -838,17 +838,17 @@ patch(
 
   /* Reallocate patch buffers */
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2y, mreq, "in geometry.c");
-  mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c");
+  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
   if( nx > 0) ntp=2;
   else ntp= ny;
@@ -977,17 +977,17 @@ patch(
 	data.m += nx*ny-1;
 	/* Reallocate patch buffers */
 	mreq = (size_t)data.m * sizeof(double);
-	mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
 	xn2= data.px[mi]- s1x- s2x;
 	yn2= data.py[mi]- s1y- s2y;
@@ -1049,21 +1049,21 @@ subph( int nx, int ny )
   else data.m += 4;
 
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
   if( !CHILD )
   {
 	mreq = (size_t)(data.n + 2 * data.m) * sizeof(GdkSegment);
-	mem_realloc( (void *)&structure_segs, mreq, "in geometry.c" );
+	mem_realloc( (void **)&structure_segs, mreq, "in geometry.c" );
   }
 
   /* Shift patches to make room for new ones */
@@ -1178,17 +1178,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 	  {
 		/* Reallocate tags buffer */
 		mreq = (size_t)(2 * data.n + data.m) * sizeof(int);
-		mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
 		/* Reallocate wire buffers */
 		mreq = (size_t)(2 * data.n) * sizeof(double);
-		mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
 		for( i = 0; i < data.n; i++ )
 		{
@@ -1232,17 +1232,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 	  {
 		/* Reallocate patch buffers */
 		mreq = (size_t)(2 * data.m) * sizeof(double);
-		mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
 		for( i = 0; i < data.m; i++ )
 		{
@@ -1283,16 +1283,16 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 	  {
 		/* Reallocate tags buffer */
 		mreq = (size_t)(2 * data.n) * sizeof(int);
-		mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 		/* Reallocate wire buffers */
 		mreq = (size_t)(2 * data.n) * sizeof(double);
-		mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
 		for( i = 0; i < data.n; i++ )
 		{
@@ -1336,17 +1336,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 	  {
 		/* Reallocate patch buffers */
 		mreq = (size_t)(2 * data.m) * sizeof(double);
-		mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-		mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+		mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
 		for( i = 0; i < data.m; i++ )
 		{
@@ -1388,17 +1388,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 	{
 	  /* Reallocate tags buffer */
 	  mreq = (size_t)(2 * data.n) * sizeof(int);
-	  mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
 	  /* Reallocate wire buffers */
 	  mreq = (size_t)(2 * data.n) * sizeof(double);
-	  mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-	  mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+	  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
 	  for( i = 0; i < data.n; i++ )
 	  {
@@ -1440,17 +1440,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
 	/* Reallocate patch buffers */
 	mreq = (size_t)(2 * data.m) * sizeof(double);
-	mem_realloc( (void *)&data.px,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.px,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
 	for( i = 0; i < data.m; i++ )
 	{
@@ -1486,7 +1486,7 @@ reflc( int ix, int iy, int iz, int iti, int nop )
   /* reproduce structure with rotation to form cylindrical structure */
   fnop= (double)nop;
   data.ipsym=-1;
-  sam=TP/ fnop;
+  sam=TWOPI/ fnop;
   cs= cos( sam);
   ss= sin( sam);
 
@@ -1497,17 +1497,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
 	/* Reallocate tags buffer */
 	mreq = (size_t)data.n * sizeof(int);
-	mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
 	/* Reallocate wire buffers */
 	mreq = (size_t)data.n * sizeof(double);
-	mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-	mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+	mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
 	for( i = nx; i < data.n; i++ )
 	{
@@ -1540,17 +1540,17 @@ reflc( int ix, int iy, int iz, int iti, int nop )
 
   /* Reallocate patch buffers */
   mreq = (size_t)data.m * sizeof(double);
-  mem_realloc( (void *)&data.px,  mreq, "in geometry.c"  );
-  mem_realloc( (void *)&data.py,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pz,  mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1y, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t1z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2x, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2y, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.t2z, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.pbi, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.psalp, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.px,  mreq, "in geometry.c"  );
+  mem_realloc( (void **)&data.py,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pz,  mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1y, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t1z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2x, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2y, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.t2z, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.pbi, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.psalp, mreq, "in geometry.c" );
 
   for( i = nx; i < data.m; i++ )
   {
@@ -1602,17 +1602,17 @@ wire( double xw1, double yw1, double zw1,
 
   /* Reallocate tags buffer */
   mreq = (size_t)data.n * sizeof(int);
-  mem_realloc( (void *)&data.itag, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.itag, mreq, "in geometry.c" );
 
   /* Reallocate wire buffers */
   mreq = (size_t)data.n * sizeof(double);
-  mem_realloc( (void *)&data.x1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.y1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.z1, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.x2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.y2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.z2, mreq, "in geometry.c" );
-  mem_realloc( (void *)&data.bi, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.x1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.y1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.z1, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.x2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.y2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.z2, mreq, "in geometry.c" );
+  mem_realloc( (void **)&data.bi, mreq, "in geometry.c" );
 
   xd= xw2- xw1;
   yd= yw2- yw1;
