@@ -79,7 +79,7 @@ Save_FreqPlots_Gnuplot_Data( char *filename )
 
 	  /* Max gain for given polarization type */
 	  gmax = rad_pattern[idx].gtot[mgidx] +
-		10.0 * log10( Polarization_Factor(pol, idx, mgidx) );
+		Polarization_Factor(pol, idx, mgidx);
 
 	  /* Net gain if selected */
 	  if( isFlagSet(PLOT_NETGAIN) )
@@ -127,8 +127,8 @@ Save_FreqPlots_Gnuplot_Data( char *filename )
 	  /* Front to back ratio */
 	  fbratio  = pow( 10.0, gmax / 10.0 );
 	  fbratio /= pow( 10.0,
-		  rad_pattern[idx].gtot[fbidx] / 10.0 +
-		  log10(Polarization_Factor(pol, idx, fbidx)) );
+		  (rad_pattern[idx].gtot[fbidx] +
+		   Polarization_Factor(pol, idx, fbidx)) / 10.0 );
 	  fbratio = 10.0 * log10( fbratio );
 
 	  if( no_fbr && isFlagClear(PLOT_NETGAIN) ) /* Plot max gain only */
@@ -313,10 +313,10 @@ Save_RadPattern_Gnuplot_Data( char *filename )
 	  if( mreq != (size_t)npts * sizeof( double ) )
 	  {
 		mreq = (size_t)npts * sizeof( double );
-		mem_realloc( (void *)&pov_x, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_y, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_z, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_r, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
 	  }
 
 	  /* Calculate Poynting vector and its max and min */
@@ -383,8 +383,8 @@ Save_RadPattern_Gnuplot_Data( char *filename )
 	double theta, phi, r;
 
 	/* theta and phi step in rads */
-	double dth = (double)fpat.dth * (double)TA;
-	double dph = (double)fpat.dph * (double)TA;
+	double dth = (double)fpat.dth * (double)TORAD;
+	double dph = (double)fpat.dph * (double)TORAD;
 
 	/* Open gplot file, abort on error */
 	if( !Open_File(&fp, filename, "w") )
@@ -394,13 +394,13 @@ Save_RadPattern_Gnuplot_Data( char *filename )
 	/* Distance of rdpattern point nearest to xyz origin */
 	/*** Convert radiation pattern values
 	 * to points in 3d space in x,y,z axis ***/
-	phi = (double)fpat.phis * (double)TA; /* In rads */
+	phi = (double)fpat.phis * (double)TORAD; /* In rads */
 
 	/* Step phi angle */
 	idx = 0;
 	for( nph = 0; nph < fpat.nph; nph++ )
 	{
-	  theta = (double)fpat.thets * (double)TA; /* In rads */
+	  theta = (double)fpat.thets * (double)TORAD; /* In rads */
 
 	  /* Step theta angle */
 	  for( nth = 0; nth < fpat.nth; nth++ )
