@@ -68,25 +68,25 @@ void netwk( complex double *cmx, int *ip, complex double *einc )
   if( netcx.nonet > 0 )
   {
 	mreq = (size_t)data.np3m * sizeof(complex double);
-	mem_alloc( (void *)&rhs, mreq, "in network.c");
+	mem_alloc( (void **)&rhs, mreq, "in network.c");
 
 	mreq = (size_t)j * sizeof(complex double);
-	mem_alloc( (void *)&rhnt, mreq, "in network.c");
-	mem_alloc( (void *)&rhnx, mreq, "in network.c");
-	mem_alloc( (void *)&cmn,  mreq * (size_t)j, "in network.c");
+	mem_alloc( (void **)&rhnt, mreq, "in network.c");
+	mem_alloc( (void **)&rhnx, mreq, "in network.c");
+	mem_alloc( (void **)&cmn,  mreq * (size_t)j, "in network.c");
 
 	mreq = (size_t)j * sizeof(int);
-	mem_alloc( (void *)&ntsca, mreq, "in network.c");
-	mem_alloc( (void *)&nteqa, mreq, "in network.c");
-	mem_alloc( (void *)&ipnt,  mreq, "in network.c");
+	mem_alloc( (void **)&ntsca, mreq, "in network.c");
+	mem_alloc( (void **)&nteqa, mreq, "in network.c");
+	mem_alloc( (void **)&ipnt,  mreq, "in network.c");
 
 	mreq = (size_t)vsorc.nsant * sizeof(complex double);
-	mem_alloc( (void *)&vsrc, mreq, "in network.c");
+	mem_alloc( (void **)&vsrc, mreq, "in network.c");
   }
   else if( netcx.masym != 0)
   {
 	mreq = (size_t)j * sizeof(int);
-	mem_alloc( (void *)&ipnt,  mreq, "in network.c");
+	mem_alloc( (void **)&ipnt,  mreq, "in network.c");
   }
 
   /* Signal new and valid current data */
@@ -243,7 +243,7 @@ void netwk( complex double *cmx, int *ip, complex double *einc )
 		}
 		else
 		{
-		  y22r= TP* netcx.x11i[j]/ data.wlam;
+		  y22r= TWOPI* netcx.x11i[j]/ data.wlam;
 		  y12r=0.0;
 		  y12i=1.0/( netcx.x11r[j]* sin( y22r));
 		  y11r= netcx.x12r[j];
@@ -518,14 +518,14 @@ void netwk( complex double *cmx, int *ip, complex double *einc )
   if( (vsorc.nsant+vsorc.nvqd) == 0)
   {
 	/* Free network buffers */
-	free_ptr( (void *)&ipnt );
-	free_ptr( (void *)&nteqa );
-	free_ptr( (void *)&ntsca );
-	free_ptr( (void *)&vsrc );
-	free_ptr( (void *)&rhs );
-	free_ptr( (void *)&cmn );
-	free_ptr( (void *)&rhnt );
-	free_ptr( (void *)&rhnx );
+	free_ptr( (void **)&ipnt );
+	free_ptr( (void **)&nteqa );
+	free_ptr( (void **)&ntsca );
+	free_ptr( (void **)&vsrc );
+	free_ptr( (void **)&rhs );
+	free_ptr( (void **)&cmn );
+	free_ptr( (void **)&rhnt );
+	free_ptr( (void **)&rhnx );
 	return;
   }
 
@@ -574,7 +574,7 @@ void netwk( complex double *cmx, int *ip, complex double *einc )
 	  cux= cmplx( crnt.air[isc1], crnt.aii[isc1]);
 	  ymit= cmplx( crnt.bir[isc1], crnt.bii[isc1]);
 	  netcx.zped= cmplx( crnt.cir[isc1], crnt.cii[isc1]);
-	  pwr= data.si[isc1]* TP*.5;
+	  pwr= data.si[isc1]* TWOPI*.5;
 	  cux=( cux- ymit* sin( pwr) +
 		  netcx.zped* cos( pwr))* data.wlam;
 	  netcx.zped= vlt/ cux;
@@ -583,14 +583,14 @@ void netwk( complex double *cmx, int *ip, complex double *einc )
 	} /* for( i = 0; i < vsorc.nvqd; i++ ) */
 
   /* Free network buffers */
-  free_ptr( (void *)&ipnt );
-  free_ptr( (void *)&nteqa );
-  free_ptr( (void *)&ntsca );
-  free_ptr( (void *)&vsrc );
-  free_ptr( (void *)&rhs );
-  free_ptr( (void *)&cmn );
-  free_ptr( (void *)&rhnt );
-  free_ptr( (void *)&rhnx );
+  free_ptr( (void **)&ipnt );
+  free_ptr( (void **)&nteqa );
+  free_ptr( (void **)&ntsca );
+  free_ptr( (void **)&vsrc );
+  free_ptr( (void **)&rhs );
+  free_ptr( (void **)&cmn );
+  free_ptr( (void **)&rhnt );
+  free_ptr( (void **)&rhnx );
 
   return;
 }
